'''
'NCP_S11.txt' is the S11 measurement data for Dish 2V, when pointing to NCP, column 1 for frequency in Hz, column 2 for S11 magnitude in dB, column 3 for S11 phase in degree.
'NCP_S21.txt' is the transmission coefficients measurement data for Dish Array, when pointing to NCP, column 1 for frequency in Hz, column 2 for S21 for 2V and 8V in dB, column 3 for S21 for 2V and 10V in dB, column 4 for S21 for 2V and 15V in dB
'zenith_S21.txt' is the transmission coefficients measurement data for Dish Array, when pointing to zenith, column definition is same as 'NCP_S21.txt'.
'''


import numpy as np
import matplotlib.pyplot as plt

NCP_S11_data = np.loadtxt('./NCP_S11.txt', delimiter=',')
freq_S11 = NCP_S11_data[:, 0]
NCP_S11_dB = NCP_S11_data[:, 1]

NCP_S21_data = np.loadtxt('./NCP_S21.txt', delimiter=',')
NCP_freq_S21 = NCP_S21_data[:, 0]
NCP_2V8V_mag = NCP_S21_data[:, 1]
NCP_2V10V_mag = NCP_S21_data[:, 2]
NCP_2V15V_mag = NCP_S21_data[:, 3]

zenith_S21_data = np.loadtxt('./zenith_S21.txt', delimiter=',')
zenith_freq_S21 = zenith_S21_data[:, 0]
zenith_2V8V_mag = zenith_S21_data[:, 1]
zenith_2V10V_mag = zenith_S21_data[:, 2]
zenith_2V15V_mag = zenith_S21_data[:, 3]


plt.figure(1)
plt.plot(freq_S11, NCP_S11_dB, label='2V S11')
plt.legend()

plt.figure(2)
plt.plot(NCP_freq_S21, NCP_2V8V_mag, label='2V-8V')
plt.plot(NCP_freq_S21, NCP_2V10V_mag, label='2V-10V')
plt.plot(NCP_freq_S21, NCP_2V15V_mag, label='2V-15V')
plt.legend()

plt.figure(3)
plt.plot(zenith_freq_S21, zenith_2V8V_mag, label='2V-8V')
plt.plot(zenith_freq_S21, zenith_2V10V_mag, label='2V-10V')
plt.plot(zenith_freq_S21, zenith_2V15V_mag, label='2V-15V')
plt.legend()

plt.show()
